=== modified file 'loggerhead/apps/filesystem.py'
--- loggerhead/apps/filesystem.py	2009-02-19 18:04:11 +0000
+++ loggerhead/apps/filesystem.py	2009-03-31 19:31:45 +0000
@@ -1,7 +1,6 @@
 """Serve branches at urls that mimic the file system layout."""
 
 import os
-import tempfile
 
 from bzrlib import branch, errors, lru_cache
 
@@ -11,10 +10,9 @@
 
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.apps import favicon_app, static_app
+from loggerhead.config import LoggerheadConfig
 from loggerhead.controllers.directory_ui import DirectoryUI
 
-sql_dir = tempfile.mkdtemp(prefix='loggerhead-cache-')
-
 
 class BranchesFromFileSystemServer(object):
 
@@ -22,6 +20,7 @@
         self.path = path
         self.root = root
         self.name = name
+        self._config = LoggerheadConfig()
 
     def app_for_branch(self, branch):
         if not self.name:
@@ -31,8 +30,9 @@
             name = self.name
             is_root = False
         branch_app = BranchWSGIApp(
-            branch, name, {'cachepath': sql_dir}, self.root.graph_cache,
-            is_root=is_root)
+            branch, name,
+            {'cachepath': self._config.SQL_DIR},
+            self.root.graph_cache, is_root=is_root)
         return branch_app.app
 
     def app_for_non_branch(self, environ):

=== added file 'loggerhead/config.py'
--- loggerhead/config.py	1970-01-01 00:00:00 +0000
+++ loggerhead/config.py	2009-03-31 21:43:03 +0000
@@ -0,0 +1,66 @@
+'''Configuration tools for Loggerhead.'''
+from optparse import OptionParser
+import sys
+import tempfile
+
+
+def command_line_parser():
+    parser = OptionParser("%prog [options] <path>")
+    parser.set_defaults(
+        user_dirs=False,
+        show_version=False,
+        log_folder=None,
+        )
+    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
+                      help="Serve user directories as ~user.")
+    parser.add_option("--trunk-dir", metavar="DIR",
+                      help="The directory that contains the trunk branches.")
+    parser.add_option("--port", dest="user_port",
+                      help=("Port Loggerhead should listen on "
+                            "(defaults to 8080)."))
+    parser.add_option("--host", dest="user_host",
+                      help="Host Loggerhead should listen on.")
+    parser.add_option('--memory-profile', action='store_true',
+                      dest='memory_profile',
+                      help='Profile the memory usage using heapy.')
+    parser.add_option("--prefix", dest="user_prefix",
+                      help="Specify host prefix.")
+    parser.add_option("--profile", action="store_true", dest="profile",
+                      help="Generate callgrind profile data to "
+                        "%d-stats.callgrind on each request.")
+    parser.add_option("--reload", action="store_true", dest="reload",
+                      help="Restarts the application when changing python"
+                           " files. Only used for development purposes.")
+    parser.add_option('--log-folder', dest="log_folder",
+                      type=str, help="The directory to place log files in.")
+    parser.add_option("--version", action="store_true", dest="show_version",
+                      help="Print the software version and exit")
+    return parser
+
+
+class LoggerheadConfig:
+    '''A configuration object.'''
+
+    def __init__(self):
+        self._parser = command_line_parser()
+        self._options, self._args = self._parser.parse_args(sys.argv[1:])
+
+        self.SQL_DIR = tempfile.mkdtemp(prefix='loggerhead-cache-')
+
+    def get_option(self, option):
+        '''Get an option from the options dict.'''
+        return getattr(self._options, option)
+
+    def get_arg(self, index):
+        '''Get an arg from the arg list.'''
+        return self._args(index)
+
+    def print_help(self):
+        '''Wrapper around OptionParser.print_help.'''
+        return self._parser.print_help()
+
+    @property
+    def arg_count(self):
+        '''Return the number of args from the option parser.'''
+        return len(self._args)
+

=== modified file 'serve-branches'
--- serve-branches	2009-03-30 22:11:06 +0000
+++ serve-branches	2009-03-31 21:47:14 +0000
@@ -19,8 +19,6 @@
 import os
 import sys
 
-from optparse import OptionParser
-
 from bzrlib.plugin import load_plugins
 
 from paste import httpserver
@@ -30,56 +28,22 @@
 from loggerhead import __version__
 from loggerhead.apps.filesystem import (
     BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
+from loggerhead.config import LoggerheadConfig
 from loggerhead.util import Reloader
 from loggerhead.apps.error import ErrorHandlerApp
 
 
-def command_line_parser():
-    parser = OptionParser("%prog [options] <path>")
-    parser.set_defaults(
-        user_dirs=False,
-        show_version=False,
-        log_folder=None,
-        )
-    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
-                      help="Serve user directories as ~user.")
-    parser.add_option("--trunk-dir", metavar="DIR",
-                      help="The directory that contains the trunk branches.")
-    parser.add_option("--port", dest="user_port",
-                      help=("Port Loggerhead should listen on "
-                            "(defaults to 8080)."))
-    parser.add_option("--host", dest="user_host",
-                      help="Host Loggerhead should listen on.")
-    parser.add_option('--memory-profile', action='store_true',
-                      dest='memory_profile',
-                      help='Profile the memory usage using heapy.')
-    parser.add_option("--prefix", dest="user_prefix",
-                      help="Specify host prefix.")
-    parser.add_option("--profile", action="store_true", dest="profile",
-                      help="Generate callgrind profile data to "
-                        "%d-stats.callgrind on each request.")
-    parser.add_option("--reload", action="store_true", dest="reload",
-                      help="Restarts the application when changing python"
-                           " files. Only used for development purposes.")
-    parser.add_option('--log-folder', dest="log_folder",
-                      type=str, help="The directory to place log files in.")
-    parser.add_option("--version", action="store_true", dest="show_version",
-                      help="Print the software version and exit")
-    return parser
-
-
 def main(args):
-    parser = command_line_parser()
-    (options, args) = parser.parse_args(sys.argv[1:])
+    config = LoggerheadConfig()
 
-    if options.show_version:
+    if config.get_option('show_version'):
         print "loggerhead %s" % __version__
         sys.exit(0)
 
-    if len(args) > 1:
-        parser.print_help()
+    if config.arg_count > 1:
+        config.print_help()
         sys.exit(1)
-    elif len(args) == 1:
+    elif config.arg_count == 1:
         [path] = args
     else:
         path = '.'
@@ -88,21 +52,22 @@
         print "%s is not a directory" % path
         sys.exit(1)
 
-    if options.trunk_dir and not options.user_dirs:
+    if config.get_option('trunk_dir') and not config.get_option('user_dirs'):
         print "--trunk-dir is only valid with --user-dirs"
         sys.exit(1)
 
-    if options.reload:
+    if config.get_option('reload'):
         if Reloader.is_installed():
             Reloader.install()
         else:
             return Reloader.restart_with_reloader()
 
-    if options.user_dirs:
-        if not options.trunk_dir:
+    if config.get_option('user_dirs'):
+        if not config.get_option['trunk_dir']:
             print "You didn't specify a directory for the trunk directories."
             sys.exit(1)
-        app = UserBranchesFromFileSystemRoot(path, options.trunk_dir)
+        app = UserBranchesFromFileSystemRoot(
+            path, config.get_option('trunk_dir'))
     else:
         app = BranchesFromFileSystemRoot(path)
 
@@ -110,8 +75,9 @@
     logging.basicConfig()
     logging.getLogger('').setLevel(logging.DEBUG)
     logger = getattr(app, 'log', logging.getLogger('loggerhead'))
-    if options.log_folder:
-        logfile_path = os.path.join(options.log_folder, 'serve-branches.log')
+    if config.get_option('log_folder'):
+        logfile_path = os.path.join(
+            config.get_option['log_folder'], 'serve-branches.log')
     else:
         logfile_path = 'serve-branches.log'
     logfile = logging.FileHandler(logfile_path, 'a')
@@ -121,24 +87,25 @@
     logfile.setLevel(logging.DEBUG)
     logger.addHandler(logfile)
 
-    memprofile = logging.getLogger('loggerhead-memprofile')
-    memprofile.setLevel(logging.DEBUG)
-    memprofile.addHandler(logging.FileHandler('loggerhead-memprofile'))
+    if config.get_option('memory_profile'):
+        memprofile = logging.getLogger('loggerhead-memprofile')
+        memprofile.setLevel(logging.DEBUG)
+        memprofile.addHandler(logging.FileHandler('loggerhead-memprofile'))
 
     # setup_logging() #end
 
     app = TransLogger(app, logger=logger)
-    if options.profile:
+    if config.get_option('profile'):
         from loggerhead.middleware.profile import LSProfMiddleware
         app = LSProfMiddleware(app)
-    if options.memory_profile:
+    if config.get_option('memory_profile'):
         from loggerhead.middleware.profile import MemoryProfileMiddleware
         app = MemoryProfileMiddleware(app)
 
-    if not options.user_prefix:
+    if not config.get_option('user_prefix'):
         prefix = '/'
     else:
-        prefix = options.user_prefix
+        prefix = config.get_option('user_prefix')
         if not prefix.startswith('/'):
             prefix = '/' + prefix
 
@@ -163,15 +130,15 @@
     app = HTTPExceptionHandler(app)
     app = ErrorHandlerApp(app)
 
-    if not options.user_port:
+    if not config.get_option('user_port'):
         port = '8080'
     else:
-        port = options.user_port
+        port = config.get_option('user_port')
 
-    if not options.user_host:
+    if not config.get_option('user_host'):
         host = '0.0.0.0'
     else:
-        host = options.user_host
+        host = config.get_option('user_host')
 
     load_plugins()
 

